## Use Cases

- [owasp-projects](docs/demos/use-cases/owasp-projects)
- [simple-asm-and-binary-execution](docs/demos/use-cases/simple-asm-and-binary-execution)
- [simple-asm-execution](docs/demos/use-cases/simple-asm-execution)
- [talk-with-ifconfig](docs/demos/use-cases/talk-with-ifconfig)